<?php
/**
 * @package     belinni
 * @version     1.1.5
 * @author      Pixelshow
 * @link        http://pixel-show.com
 * @copyright   Copyright (c) 2017 Pixelshow
 * @license     GPL v2
 */

/**
 * Set the theme's content width.
 */
if ( ! isset( $content_width ) )
	$content_width = 1170;

/**
 * Theme set up
 */
add_action( 'after_setup_theme', 'pixelshow_theme_setup' );

if ( !function_exists('pixelshow_theme_setup') ) {

	function pixelshow_theme_setup() {

		// Register menu
		register_nav_menus(
			array(
				'primary-menu' => esc_html__( 'Primary Menu', 'belinni' ),
			)
		);

		// Localization
		load_theme_textdomain('belinni', get_template_directory() . '/languages');

		// Post formats
		add_theme_support( 'post-formats', array( 'gallery', 'video', 'audio', 'quote' ) );

		// Featured image
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'belinni-big-slider', 1140, 540, true );
		add_image_size( 'belinni-full-post', 780, 450, true );
		add_image_size( 'belinni-middle-size', 640, 430, true );
		add_image_size( 'belinni-masonry-size', 550);
		add_image_size( 'belinni-post-grid', 420, 320, true );
		add_image_size( 'belinni-latest-side', 80, 80, true );

		// Feed Links
		add_theme_support( 'automatic-feed-links' );

		// Page Title
		add_theme_support( 'title-tag' );

		//Woocommerce support
		add_theme_support( 'woocommerce' );
	}
}
function belinni_remove_script_version( $src ){
	$parts = explode( '?ver', $src );
	return $parts[0];
}
add_filter( 'script_loader_src', 'belinni_remove_script_version', 15, 1 );
add_filter( 'style_loader_src', 'belinni_remove_script_version', 15, 1 );

/**
 * PostViews
 */
function pixelshow_getPostViews($postID){
	$count_key = 'belinni_post_views_count';
	$count = get_post_meta($postID, $count_key, true);
	if($count==''){
		delete_post_meta($postID, $count_key);
		add_post_meta($postID, $count_key, '0');
		return "0";
	}
	return $count.'';
}
function pixelshow_setPostViews($postID) {
	$count_key = 'belinni_post_views_count';
	$count = get_post_meta($postID, $count_key, true);
	if($count==''){
		$count = 0;
		delete_post_meta($postID, $count_key);
		add_post_meta($postID, $count_key, '0');
	}else{
		$count++;
		update_post_meta($postID, $count_key, $count);
	}
}
remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);

/**
 * Get theme mod
 */
if( !function_exists( 'pixelshow_get_theme_mod' ) ) {
	function pixelshow_get_theme_mod( $key, $default ) {
		return get_theme_mod( $key, $default );
	}
}

/**
 * Fonts url
 */
if( !function_exists( 'pixelshow_belinni_fonts_url' ) ){
	function pixelshow_belinni_fonts_url() {
		$fonts_url = '';
		$fonts     = array();
		$subsets   = 'latin';

		$body_font = pixelshow_get_fonts( pixelshow_get_theme_mod( 'pixelshow_pxs_body_font_family', 'open_sans' ) );
		$headings_font = pixelshow_get_fonts( pixelshow_get_theme_mod( 'pixelshow_pxs_heading_font_family', 'poppins' ) );

		// Main font
		$fonts[ pixelshow_get_theme_mod( 'pixelshow_pxs_body_font_family', 'open_sans' ) ] = isset( $body_font['link'] ) ? $body_font['link'] : '';

		// Heading font
		$fonts[ pixelshow_get_theme_mod( 'pixelshow_pxs_heading_font_family', 'poppins' ) ] = isset( $headings_font['link'] ) ? $headings_font['link'] : '';

		if ( $fonts ) {
			$fonts_url = add_query_arg( array(
				'family' => implode( '%7C', $fonts ),
				'subset' => $subsets,
			), 'https://fonts.googleapis.com/css' );
		}
		return $fonts_url;
	}
}

/**
 * Register & enqueue styles/scripts
 */
add_action( 'wp_enqueue_scripts', 'pixelshow_load_scripts' );

function pixelshow_load_scripts() {

	// Register scripts and styles
	wp_enqueue_style( 'belinni-fonts', pixelshow_belinni_fonts_url(), array(), null );
	wp_enqueue_style('font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', array(), null);
	wp_enqueue_style('plugins-styles', get_template_directory_uri() . '/css/plugins-styles.css', array(), null);
	wp_enqueue_style('default', get_template_directory_uri() . '/css/woocommerce.css', array(), null);
	wp_enqueue_style('belinni-main-styles', get_template_directory_uri() . '/style.css', array(), null);
	wp_enqueue_style('responsive', get_template_directory_uri() . '/css/media.css', array(), null);

	wp_enqueue_script('plugins' ,get_template_directory_uri(). '/js/plugins.js', array('jquery'), '1.0.0', true);
	wp_enqueue_script('belinni-main-scripts', get_template_directory_uri(). '/js/main.js', array('jquery'), '1.0.0', true);

	if (is_singular() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
}

/**
 * Add title back to images
 */
function pixelshow_add_title_to_attachment( $markup, $id ){
	$att = get_post( $id );
	return str_replace('<a ', '<a title="'.$att->post_title.'" ', $markup);
}
add_filter('wp_get_attachment_link', 'pixelshow_add_title_to_attachment', 10, 5);

/**
 * Woocommerce Cart
 */
add_filter( 'woocommerce_widget_cart_is_hidden', 'always_show_cart', 40, 0 );
function always_show_cart() {
	return false;
}

/**
 * TinyMCE
 */
function pixelshow_add_editor_styles() {
	add_editor_style( 'css/editor-styles.css' );
}
add_action( 'current_screen', 'pixelshow_add_editor_styles' );

/**
 * LazyLoad
 */
function pixelshow_lazyload_img(){
	$lazy_placeholder_image = get_template_directory_uri(). '/img/lazyload.jpg';
	return $lazy_placeholder_image;
}

/**
 * Include files
 */
// Theme Options
require_once(get_template_directory() .'/functions/customizer/pxs-custom-controller.php');
require_once(get_template_directory() .'/functions/customizer/pxs-customizer-settings.php');
require_once(get_template_directory() .'/functions/customizer/pxs-customizer-style.php');

// Widgets
require_once(get_template_directory() .'/inc/widgets/about-widget.php');
require_once(get_template_directory() .'/inc/widgets/social-widget.php');
require_once(get_template_directory() .'/inc/widgets/post-widget.php');
require_once(get_template_directory() .'/inc/widgets/sliderpost-widget.php');
require_once(get_template_directory() .'/inc/widgets/facebook-widget.php');
require_once(get_template_directory() .'/inc/widgets/tabs-widget.php');
require_once(get_template_directory() .'/inc/widgets/flickr.php');
require_once(get_template_directory() .'/inc/widgets/pinterest.php');

/**
 * Post-likes
 */
require_once(get_template_directory() .'/inc/templates/post-tmp/post-like.php');

/**
 * Register widget areas
 */
if ( function_exists('register_sidebar') ) {
	register_sidebar(array(
		'name' => esc_html__( 'Sidebar', 'belinni' ),
		'id' => 'sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
	));
	register_sidebar(array(
		'name' => esc_html__( 'Glide Sidebar', 'belinni' ),
		'id' => 'glide_sidebar',
		'before_widget' => '<div id="%1$s" class="widget glide-widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="glide-widget-title">',
		'after_title' => '</h4>',
	));
	register_sidebar(array(
		'name' => esc_html__( 'Header Woocommerce Cart', 'belinni' ),
		'id' => 'header_woocommerce_cart',
		'before_widget' => '<div id="%1$s" class="widget header_woocommerce_cart %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="header-widget-cart-title">',
		'after_title' => '</h4>',
		'description' => esc_html__( 'IMPORTANT: This area is used for Woocommerce Cart Widget', 'belinni' ),
	));
	register_sidebar(array(
		'name' => esc_html__( 'Instagram Footer', 'belinni' ),
		'id' => 'footer_insta',
		'before_widget' => '<div id="%1$s" class="widget footer-insta %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>'
	));
	register_sidebar(array(
		'name' => esc_html__( 'Footer Left Side', 'belinni' ),
		'id' => 'footer_part_1',
		'before_widget' => '<div id="%1$s" class="widget footer-left-side %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>'
	));
	register_sidebar(array(
		'name' => esc_html__( 'Footer Center Block', 'belinni' ),
		'id' => 'footer_part_2',
		'before_widget' => '<div id="%1$s" class="widget footer-center-block %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>'
	));
	register_sidebar(array(
		'name' => esc_html__( 'Footer Right Side', 'belinni' ),
		'id' => 'footer_part_3',
		'before_widget' => '<div id="%1$s" class="widget footer-right-side %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>'
	));

	register_sidebar(array(
		'name' => esc_html__( 'ADS Above Header', 'belinni' ),
		'id' => 'prom_above_header',
		'before_widget' => '<div id="%1$s" class="widget prom-widget prom-above-header %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
		'description' => esc_html__( 'IMPORTANT: This area is used for ADS Banners and Text Widget', 'belinni' ),
	));
	register_sidebar(array(
		'name' => esc_html__( 'ADS in Header Layout', 'belinni' ),
		'id' => 'prom_in_header',
		'before_widget' => '<div id="%1$s" class="widget prom-widget prom-in-header %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
		'description' => esc_html__( 'IMPORTANT: This area displays ads inside the header. To do this, add a text widget with your banner here. Then activate the required view of the header: Appearance -> Customize -> Logo and Header -> Header Layout -> Select the 9 type of header', 'belinni' ),
	));
	register_sidebar(array(
		'name' => esc_html__( 'ADS Above Slider', 'belinni' ),
		'id' => 'prom_above_slider',
		'before_widget' => '<div id="%1$s" class="widget prom-widget prom-above-slider %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
		'description' => esc_html__( 'IMPORTANT: This area is used for ADS Banners and Text Widget', 'belinni' ),
	));
	register_sidebar(array(
		'name' => esc_html__( 'ADS Under Slider', 'belinni' ),
		'id' => 'prom_under_slider',
		'before_widget' => '<div id="%1$s" class="widget prom-widget prom-under-slider %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
		'description' => esc_html__( 'IMPORTANT: This area is used for ADS Banners and Text Widget', 'belinni' ),
	));
	register_sidebar(array(
		'name' => esc_html__( 'ADS Above Most Popular Posts', 'belinni' ),
		'id' => 'prom_above_mpp',
		'before_widget' => '<div id="%1$s" class="widget prom-widget prom-above-mpp %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
		'description' => esc_html__( 'IMPORTANT: This area is used for ADS Banners and Text Widget', 'belinni' ),
	));
	register_sidebar(array(
		'name' => esc_html__( 'ADS Under Most Popular Posts', 'belinni' ),
		'id' => 'prom_under_mpp',
		'before_widget' => '<div id="%1$s" class="widget prom-widget prom-under-mpp %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
		'description' => esc_html__( 'IMPORTANT: This area is used for ADS Banners and Text Widget', 'belinni' ),
	));
}

/**
 * Comments
 */
function pixelshow_comments($pixelshow_comment, $args, $depth) {
	$GLOBALS['pixelshow_comment'] = $pixelshow_comment;
	?>
<div <?php comment_class('list-comments'); ?> id="comment-<?php comment_ID() ?>">
	<div class="thecomment">

		<div class="author-img">
			<?php echo get_avatar($pixelshow_comment,$args['avatar_size']); ?>
		</div>

		<div class="comment-text">
				<span class="reply">
					<?php comment_reply_link(array_merge( $args, array('reply_text' => __('Reply', 'belinni'), 'depth' => $depth, 'max_depth' => $args['max_depth'])), $pixelshow_comment->comment_ID); ?>
					<?php edit_comment_link(__('Edit', 'belinni')); ?>
				</span>
			<span class="author"><?php echo get_comment_author_link(); ?></span>
			<span class="date"><?php printf(__('%1$s at %2$s', 'belinni'), get_comment_date(),  get_comment_time()) ?></span>
			<?php if ($pixelshow_comment->comment_approved == '0') : ?>
				<em><i class="icon-info-sign"></i> <?php _e('Comment awaiting approval', 'belinni'); ?></em>
				<br />
			<?php endif; ?>
			<?php comment_text(); ?>
		</div>

	</div>
	<?php
}

/**
 * Remove more link
 */
function pixelshow_remove_more_link_scroll( $link ) {
	$link = preg_replace( '|#more-[0-9]+|', '', $link );
	return $link;
}
add_filter( 'the_content_more_link', 'pixelshow_remove_more_link_scroll' );

/**
 * Exclude
 */
function pixelshow_category($separator) {

	if(get_theme_mod( 'pixelshow_pxs_featured_cat_hide' ) == true) {

		$excluded_cat = get_theme_mod('pixelshow_pxs_featured_cat');
		$first_time = 1;
		foreach((get_the_category()) as $category) {
			if ($category->cat_ID != $excluded_cat) {
				if ($first_time == 1) {
					echo '<a href="' . get_category_link( $category->term_id ) . '" title="' . sprintf( __( "View all posts in %s", "belinni" ), $category->name ) . '" ' . '>'  . $category->name.'</a>';
					$first_time = 0;
				} else {
					echo $separator . '<a href="' . get_category_link( $category->term_id ) . '" title="' . sprintf( __( "View all posts in %s", "belinni" ), $category->name ) . '" ' . '>' . $category->name.'</a>';
				}
			}
		}
	} else {

		$first_time = 1;
		foreach((get_the_category()) as $category) {
			if ($first_time == 1) {
				echo '<a href="' . get_category_link( $category->term_id ) . '" title="' . sprintf( __( "View all posts in %s", "belinni" ), $category->name ) . '" ' . '>'  . $category->name.'</a>';
				$first_time = 0;
			} else {
				echo $separator . '<a href="' . get_category_link( $category->term_id ) . '" title="' . sprintf( __( "View all posts in %s", "belinni" ), $category->name ) . '" ' . '>' . $category->name.'</a>';
			}
		}
	}
}

/**
 * Redefine the search form structure
 */
if ( ! function_exists( 'belinni_search_form' ) ) {
	function belinni_search_form( $form ) {
		$form = '
		<form role="search" method="get" class="search-form" action="' . esc_url( home_url( '/' ) ) . '">
			<input type="text" placeholder="' . esc_html__('Search...', 'belinni') . '" name="s" />
			<button type="submit" class="btn btn-default"></button>
		</form>';
		return $form;
	}
}
add_filter( 'get_search_form', 'belinni_search_form' );

/**
 * Except
 */
function pixelshow_custom_excerpt_length( $length ) {
	return 200;
}
add_filter( 'excerpt_length', 'pixelshow_custom_excerpt_length', 999 );

function pixelshow_string_limit_words($string, $word_limit)
{
	$words = explode(' ', $string, ($word_limit + 1));
	if(count($words) > $word_limit) {
		array_pop($words);
	}
	return implode(' ', $words);
}

/**
 * Gif Support
 */
function disable_upload_sizes( $sizes, $metadata ) {
	$filetype = wp_check_filetype($metadata['file']);
	if($filetype['type'] == 'image/gif') {
		$sizes = array();
	}
	return $sizes;
}
add_filter('intermediate_image_sizes_advanced', 'disable_upload_sizes', 10, 2);

/**
 * Register the required plugins
 */
require_once(get_template_directory() .'/class-tgm-plugin-activation.php');

add_action( 'belinni_register', 'pixelshow_theme_register_required_plugins' );
function pixelshow_theme_register_required_plugins() {

	$plugins = array(
		// This is an example of how to include a plugin pre-packaged with a theme.
		array(
			'name'               => esc_html__('Belinni Theme Addons', 'belinni' ),
			'slug'               => 'belinni-theme-addons',
			'source'             => get_template_directory() . '/plugins/belinni-theme-addons.zip',
			'required'           => true
		),
		//Vafpress Post Formats UI
		array(
			'name'               => esc_html__('Vafpress Post Formats UI', 'belinni' ),
			'slug'               => 'vafpress-post-formats-ui-develop',
			'source'             => get_template_directory() . '/plugins/vafpress-post-formats-ui-develop.zip',
			'required'           => true
		),
		//Visual Composer
		array(
			'name'               => esc_html__('WPBakery Visual Composer', 'belinni' ),
			'slug'               => 'js_composer',
			'version'           =>  '5.2.1',
			'source'             => get_template_directory() . '/plugins/js_composer.zip',
			'required'           => false
		),
		//One Click Demo Import
		array(
			'name'     				=> esc_html__('One Click Demo Import', 'belinni' ),
			'slug'     				=> 'one-click-demo-import',
			'required' 				=> true,
			'force_activation' 		=> false,
			'force_deactivation' 	=> false,
		),
		//Instagram Feed
		array(
			'name'     				=> esc_html__('Instagram Feed', 'belinni'),
			'slug'     				=> 'instagram-feed',
			'required' 				=> false
		),
		//Contact Form 7
		array(
			'name'     				=> esc_html__('Contact Form 7', 'belinni' ),
			'slug'     				=> 'contact-form-7',
			'required' 				=> false
		),
		//Retina
		array(
			'name'     				=> esc_html__('WP Retina 2x', 'belinni' ),
			'slug'     				=> 'wp-retina-2x',
			'required' 				=> false
		),
		//MailChimp for WordPress
		array(
			'name'     				=> esc_html__('MailChimp for WordPress (Newsletter signup)', 'belinni' ),
			'slug'     				=> 'mailchimp-for-wp',
			'required' 				=> false
		),
		//Envato Wordpress Toolkit
        array(
            'name' => esc_html__('Envato Market', 'mint'),
            'slug' => 'envato-market',
            'source' => 'https://envato.github.io/wp-envato-market/dist/envato-market.zip',
            'required' => false,
        ),
		//Loco Translation Manager
		array(
			'name'     				=> esc_html__('Loco Translation Manager', 'belinni' ),
			'slug'     				=> 'loco-translate',
			'required' 				=> false
		),
		//Mashshare Share Buttons
		array(
			'name'     				=> esc_html__('Mashshare Share Buttons', 'belinni' ),
			'slug'     				=> 'mashsharer',
			'required' 				=> false
		),
		//Woocommerce
		array(
			'name'     				=> 'WooCommerce',
			'slug'     				=> 'woocommerce',
			'required'				=> false
		),
		//Simple Image
		array(
			'name'     				=> 'Simple Image Widget',
			'slug'     				=> 'simple-image-widget',
			'required'				=> false
		)
	);

	$config = array(
		'id'           => 'belinni',
		'default_path' => '',
		'menu'         => 'belinni-install-plugins',
		'parent_slug'  => 'themes.php',
		'capability'   => 'edit_theme_options',
		'has_notices'  => true,
		'dismissable'  => true,
		'dismiss_msg'  => '',
		'is_automatic' => false,
		'message'      => '',
	);

	belinni( $plugins, $config );
}
