<?php
/**
 * @package     belinni
 * @version     1.1.5
 * @author      Pixelshow
 * @link        http://pixel-show.com
 * @copyright   Copyright (c) 2017 Pixelshow
 * @license     GPL v2
 */

add_action( 'customize_register', 'pixelshow_customize_register' );
function pixelshow_customize_register($wp_customize) {

	class Pixelshow_Customize_Number_Control extends WP_Customize_Control {
		public $type = 'number';

		public function render_content() {
			?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<input type="number" name="quantity" <?php $this->link(); ?> value="<?php echo esc_textarea( $this->value() ); ?>" style="width:70px;">
			</label>
			<?php
		}
	}

	//Custom Css Type
	class Pixelshow_Customize_CustomCss_Control extends WP_Customize_Control {
		public $type = 'custom_css';
	 
		public function render_content() { ?>
			<label><span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			<textarea style="width:100%; height:150px;" <?php $this->link(); ?>><?php echo esc_html( $this->value() ); ?></textarea></label>
		<?php }
		
	}
	
	//Radio Input
	class Pixelshow_Customize_Radio_Image_Control extends WP_Customize_Control {
		public $type  = 'radio-image';
		public $default = '';
	
		public function render_content() {
			if ( empty( $this->choices ) ) {
				return;
			}
			$name = '_customize-radio-' . $this->id; ?>
			<span class="customize-control-title">
				<?php echo esc_attr( $this->label ); ?>
				<?php if ( ! empty( $this->description ) ) : ?>
					<span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
				<?php endif; ?>
			</span>
			<div id="input_<?php echo esc_html( $this->id ); ?>" class="pixelshow-radio-image-control">
				<?php foreach ( $this->choices as $value => $label ) : ?>
					<input class="radio-image" type="radio" value="<?php echo esc_attr( $value ); ?>" id="<?php echo esc_html( $this->id . $value ); ?>" name="<?php echo esc_attr( $name ); ?>" <?php $this->link(); checked( $this->value(), $value ); ?>>
						<label for="<?php echo esc_html( $this->id . $value ); ?>">
							<img src="<?php echo esc_html( $label['image'] ); ?>" alt="<?php echo esc_attr( $label['title'] ); ?>" title="<?php echo esc_attr( $label['title'] ); ?>"><br>
							<?php echo esc_attr( $label['title'] ); ?>
						</label>
					</input>
				<?php endforeach; ?>
			</div>
			<?php 
		}
	}
	
	//Slider Type
	class Pixelshow_Customize_Slider_Control extends WP_Customize_Control {
		public $type = 'slider';
		public function enqueue() {
			wp_enqueue_script( 'jquery-ui-slider' );
		}

		public function render_content() { ?>
			<label>
				<span class="customize-control-title">
					<?php echo esc_attr( $this->label ); ?>
					<?php if ( ! empty( $this->description ) ) : ?>
						<span class="description customize-control-description"><?php echo $this->description; ?></span>
					<?php endif; ?>
				</span>
				<input type="text" class="pixelshow-slider" id="input_<?php echo $this->id; ?>" value="<?php echo esc_attr( $this->value() ); ?>" <?php $this->link(); ?>/>
			</label>

			<div id="slider_<?php echo $this->id; ?>" class="ss-slider"></div>
			<script>
			jQuery(document).ready(function($) {
				$( '[id="slider_<?php echo $this->id; ?>"]' ).slider({
						value : <?php echo esc_attr( $this->value() ); ?>,
						min   : <?php echo ($this->choices['min']) ? $this->choices['min'] : '0'; ?>,
						max   : <?php echo ($this->choices['max']) ? $this->choices['max'] : '100'; ?>,
						step  : <?php echo ($this->choices['step']) ? $this->choices['step'] : '1'; ?>,
						slide : function( event, ui ) { $( '[id="input_<?php echo $this->id; ?>"]' ).val(ui.value).keyup(); }
				});
				$( '[id="input_<?php echo $this->id; ?>"]' ).val( $( '[id="slider_<?php echo $this->id; ?>"]' ).slider( "value" ) );

				$( '[id="input_<?php echo $this->id; ?>"]' ).change(function() {
					$( '[id="slider_<?php echo $this->id; ?>"]' ).slider({
						value : $( this ).val()
					});
				});

			});
			</script>
			<?php
		}
	}
	
	//Toggle Checkbox
	class WP_Customize_ToggleCheckbox_Control extends WP_Customize_Control {
		public $type = 'toggle-checkbox';
		public function render_content() {
		?>
			<label class="toggle-checkbox-wrapper">
				<div class="customize-control-<?php echo esc_html( $this->type ); ?>-checkbox ">
					<input type="checkbox" class="belinni-toggle" id="<?php echo esc_attr( $this->id ); ?>-checkbox" value="1"
					<?php $this->link(); checked( $this->value(), 1 ); ?> />
					<label for="<?php echo esc_attr( $this->id ); ?>-checkbox"></label>
					<span class="customize-control-title customize-control-toggle"><?php echo esc_html( $this->label ); ?></span>
				</div>
			</label>
		<?php }
	}
}

if (class_exists('WP_Customize_Control')) {
    class Pixelshow_WP_Customize_Category_Control extends WP_Customize_Control {

        public function render_content() {
            $dropdown = wp_dropdown_categories(
                array(
                    'name'              => '_customize-dropdown-categories-' . $this->id,
                    'echo'              => 0,
                    'show_option_none'  => __( '&mdash; Select &mdash;', 'belinni' ),
                    'option_none_value' => '0',
                    'selected'          => $this->value(),
                )
            );
 
            $dropdown = str_replace( '<select', '<select ' . $this->get_link(), $dropdown );
            printf(
                '<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
                $this->label,
                $dropdown
            );
        }
    }
}

/*
 * Sanitizations
 * */

/* Image sanitization callback example. */
function belinni_sanitize_image( $image, $setting ) {
	$mimes = array(
		'jpg|jpeg|jpe' => 'image/jpeg',
		'gif'          => 'image/gif',
		'png'          => 'image/png',
		'bmp'          => 'image/bmp',
		'tif|tiff'     => 'image/tiff',
		'ico'          => 'image/x-icon'
	);
	$file = wp_check_filetype( $image, $mimes );
	return ( $file['ext'] ? $image : $setting->default );
}

/* Select sanitization callback */
function belinni_sanitize_select( $input, $setting ) {
	$input = sanitize_key( $input );
	$choices = $setting->manager->get_control( $setting->id )->choices;
	return ( array_key_exists( $input, $choices ) ? $input : $setting->default );
}

/* Checkbox sanitization callback */
function belinni_sanitize_checkbox( $checked ) {
	return ( ( isset( $checked ) && true == $checked ) ? true : false );
}

/* Number sanitization callback */
function belinni_sanitize_number( $number, $setting ) {
	$number = absint( $number );
	return ( $number ? $number : $setting->default );
}

/* HEX Color sanitization callback */
function belinni_sanitize_hex_color( $color ) {
	if ( '' === $color ) {
		return '';
	}
	if ( preg_match('|^#([A-Fa-f0-9]{3}){1,2}$|', $color ) ) {
		return $color;
	}
}

/* No-HTML sanitization callback */
function belinni_sanitize_nohtml( $nohtml ) {
	return wp_filter_nohtml_kses( $nohtml );
}

/* HTML sanitization callback */
function belinni_sanitize_html( $html ) {
	return wp_filter_post_kses( $html );
}

/* CSS sanitization callback */
function belinni_sanitize_css( $css ) {
	return wp_strip_all_tags( $css );
}

?>