<?php
/**
 * @package     belinni
 * @version     1.1.5
 * @author      Pixelshow
 * @link        http://pixel-show.com
 * @copyright   Copyright (c) 2017 Pixelshow
 * @license     GPL v2
 
 Plugin Name: Last Posts Slider
 */

add_action( 'widgets_init', 'pixelshow_slider_news_load_widget' );

function pixelshow_slider_news_load_widget() {
	register_widget( 'slider_news_widget' );
}

class slider_news_widget extends WP_Widget {

	/**
	 * Widget setup.
	 */
	function __construct()
	{
		$widget_ops = array( 'classname' => 'slider_news_widget', 'description' => esc_html__('A widget that displays posts carousel from all categories or a certain', 'belinni') );
		$control_ops = array( 'width' => 250, 'height' => 300, 'id_base' => 'slider_news_widget' );
		parent::__construct( 'slider_news_widget', esc_html__('Belinni: Posts Carousel', 'belinni'), $widget_ops, $control_ops );
	}

	/**
	 * How to display the widget on the screen.
	 */
	function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		$title = apply_filters('widget_title', $instance['title'] );
		$categories = $instance['categories'];
		$number = $instance['number'];
		
		$query = array('showposts' => $number, 'nopaging' => 0, 'post_status' => 'publish', 'ignore_sticky_posts' => 1, 'cat' => $categories);
		
		$loop = new WP_Query($query);
		if ($loop->have_posts()) :
		
		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $title )
			echo $before_title . $title . $after_title;

		?>

			<div class="hero">
				<div class="owl-carousel carousel-default">

					<?php  while ($loop->have_posts()) : $loop->the_post(); ?>
					  <div <?php if(has_post_thumbnail()) : ?>style="background-image: url(<?php $image = wp_get_attachment_image_src( get_post_thumbnail_id($loop->ID), 'belinni-big-slider' ); echo esc_attr($image[0]); ?>);"<?php endif; ?> class="item">
						<div class="widget-slide-info">
							<h4><a href="<?php echo get_permalink(); ?>"><?php the_title(); ?></a></h4>
							<div class="date"><a><?php the_time( get_option('date_format') ); ?></a></div>
							<p class="hero-more"><a href="<?php echo get_permalink(); ?>" class="more-link"><span class="more-button"><?php echo esc_html_e( 'Continue Reading', 'belinni' ); ?></span></a></p>
						</div>
					  </div>
					<?php endwhile; ?>

					<?php wp_reset_postdata(); ?>
					<?php endif; ?>
				</div>
			</div>
		<?php

		/* After widget (defined by themes). */
		echo $after_widget;
	}

	/**
	 * Update the widget settings.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['categories'] = $new_instance['categories'];
		$instance['number'] = strip_tags( $new_instance['number'] );

		return $instance;
	}

	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array( 'title' => esc_html__('Latest Posts', 'belinni'), 'number' => 5, 'categories' => '');
		$instance = wp_parse_args( (array) $instance, $defaults ); ?>
		
		<!-- Category -->
		<p>
		<label for="<?php echo esc_attr($this->get_field_id('categories')); ?>"><?php echo esc_html( 'Filter by Category:', 'belinni' ); ?></label> 
		<select id="<?php echo esc_attr($this->get_field_id('categories')); ?>" name="<?php echo esc_attr($this->get_field_name('categories')); ?>" class="belinnifat categories" style="width:100%;">
			<option value='all' <?php if ('all' == $instance['categories']) echo 'selected="selected"'; ?>><?php echo esc_html( 'All categories', 'belinni' ); ?></option>
			<?php $categories = get_categories('hide_empty=0&depth=1&type=post'); ?>
			<?php foreach($categories as $category) { ?>
			<option value='<?php echo esc_attr($category->term_id); ?>' <?php if ($category->term_id == $instance['categories']) echo 'selected="selected"'; ?>><?php echo esc_attr($category->cat_name); ?></option>
			<?php } ?>
		</select>
		</p>
		
		<!-- Number of posts -->
		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'number' )); ?>"><?php _e('Number of posts to show:', 'belinni'); ?></label>
			<input  type="text" class="belinnifat" id="<?php echo esc_attr($this->get_field_id( 'number' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'number' )); ?>" value="<?php echo esc_attr($instance['number']); ?>" size="3" />
		</p>

	<?php
	}
}

?>